@@ -8,6 +8,7 @@
 from __future__ import absolute_import, division, unicode_literals
 
 import logging
+import weakref
 
 from mo_future import is_text, text
 from mo_kwargs import override
@@ -49,11 +50,12 @@ class StructuredLogger_usingLogger(StructuredLogger):
 
     def stop(self):
         try:
-            self.logger.shutdown()
-        except Exception:
+            handlers = [weakref.ref(h, logging._removeHandlerRef) for h in self.logger.handlers]
+            logging.shutdown(handlers)
+        except Exception as cause:
             import sys
 
-            sys.stderr.write("Failure in the logger shutdown")
+            sys.stderr.write("Failure in the logger shutdown "+str(cause))
 
 
 MAP = {
